@@ -20,6 +20,14 @@ var collectOperatorScenarios = []expressionScenario{
 			"D0, P[], (!!seq)::- 1\n- 2\n- 3\n",
 		},
 	},
+	{
+		skipDoc:     true,
+		description: "update in collect",
+		expression:  `[.a = "cat"]`,
+		expected: []string{
+			"D0, P[], (!!seq)::- a: cat\n",
+		},
+	},
 	{
 		description: "Collect empty",
 		document:    ``,
@@ -29,14 +37,23 @@ var collectOperatorScenarios = []expressionScenario{
 		},
 	},
 	{
-		skipDoc:  true,
-		document: "{a: apple}\n---\n{b: frog}",
-
+		skipDoc:    true,
+		document:   "{a: apple}\n---\n{b: frog}",
 		expression: `[.]`,
 		expected: []string{
 			"D0, P[], (!!seq)::- {a: apple}\n- {b: frog}\n",
 		},
 	},
+	{
+		description: "with comments",
+		skipDoc:     true,
+		document:    "# abc\n[{a: apple}]\n\n# xyz\n",
+
+		expression: `[.[]]`,
+		expected: []string{
+			"D0, P[], (!!seq)::- {a: apple}\n",
+		},
+	},
 	{
 		skipDoc:    true,
 		document:   ``,
