@@ -13,6 +13,12 @@ var variableOperatorScenarios = []expressionScenario{
 			"D0, P[], (doc)::{}\n",
 		},
 	},
+	{
+		skipDoc:       true,
+		document:      `{}`,
+		expression:    `.a.b as $foo`,
+		expectedError: "must use variable with a pipe, e.g. `exp as $x | ...`",
+	},
 	{
 		document:      "a: [cat]",
 		skipDoc:       true,
